package eu.mhsl.craftattack.worldmuseum;

import eu.mhsl.craftattack.worldmuseum.commands.GamemodeCommand;
import eu.mhsl.craftattack.worldmuseum.commands.GcCommand;
import eu.mhsl.craftattack.worldmuseum.commands.TeleportCommand;
import eu.mhsl.craftattack.worldmuseum.listener.ChunkUnloading;
import eu.mhsl.craftattack.worldmuseum.listener.ClickListener;
import eu.mhsl.craftattack.worldmuseum.util.Config;
import eu.mhsl.craftattack.worldmuseum.worlds.World;
import eu.mhsl.craftattack.worldmuseum.worlds.WorldManager;
import net.minestom.server.MinecraftServer;
import net.minestom.server.coordinate.Pos;
import net.minestom.server.entity.GameMode;
import net.minestom.server.entity.Player;
import net.minestom.server.event.GlobalEventHandler;
import net.minestom.server.event.player.PlayerChunkUnloadEvent;
import net.minestom.server.event.player.PlayerLoginEvent;
import net.minestom.server.event.player.PlayerUseItemEvent;
import net.minestom.server.instance.InstanceContainer;
import net.minestom.server.instance.InstanceManager;
import net.minestom.server.instance.block.Block;
import net.minestom.server.timer.TaskSchedule;


import java.util.ArrayList;
import java.util.List;

public class Main {
    static int PORT = 25565;
    static String IP = "0.0.0.0";

    public static void main(String[] args) {
        // Initialization
        System.setProperty("minestom.chunk-view-distance", "16");
        MinecraftServer minecraftServer = MinecraftServer.init();
        InstanceManager instanceManager = MinecraftServer.getInstanceManager();

        //temp
        MinecraftServer.getSchedulerManager().scheduleTask(new TablistUpdateTask(), TaskSchedule.tick(20), TaskSchedule.tick(20));

        //load eu.mhsl.craftattack.worldmuseum.worlds / configExample file
        WorldManager worldManager = WorldManager.getInstance();
        worldManager.loadWorlds();

        //load main config
        Config config = Config.getInstance();
        config.loadConfig();
        World startworld = config.getStart_world();

        // Add an event callback to specify the spawning instance (and the spawn position)
        GlobalEventHandler globalEventHandler = MinecraftServer.getGlobalEventHandler();

        //listeners
        globalEventHandler.addListener(PlayerUseItemEvent.class, new ClickListener());
        globalEventHandler.addListener(PlayerChunkUnloadEvent.class, new ChunkUnloading());

        //commands
        MinecraftServer.getCommandManager().register(new TeleportCommand());
        MinecraftServer.getCommandManager().register(new GcCommand());
        MinecraftServer.getCommandManager().register(new GamemodeCommand());

        globalEventHandler.addListener(PlayerLoginEvent.class, event -> {
            final Player player = event.getPlayer();
            event.setSpawningInstance(startworld);
            player.setRespawnPoint(startworld.getSpawn());
            player.setGameMode(GameMode.CREATIVE);




//            for (int i = 0; i< WorldManager.getInstance().getWorlds().size(); i++) {
//                if (WorldManager.getInstance().getWorlds().get(i).isEnabled()) {
//                    player.getInventory().setItemStack(i, WorldManager.getInstance().getWorlds().get(i).getItem());
//                } else {
//                    System.out.println("Es gibt nicht aktivierte Welten!");
//                }
//            }
        });

        try {
            PORT = Integer.parseInt(args[0]);
        } catch (Exception e) {
            if (args.length != 0) System.out.println("Given port doesn't work.");
        }
        // Start the server on port default port 25565 if none is given
        System.out.println("Running on " + IP + ":" + PORT);
        minecraftServer.start(IP, PORT);
    }
}